Animation class final

The animation that is used to switch between states.

Constructors

Animation({AnimationType type = AnimationType.Linear, double duration = 0.0})
const

Properties

duration → double
Animation duration, in seconds.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → AnimationType
Animation type.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Animation other) → bool
The equality operator.
override