Attribution class abstract final

Details about the source of information.

Implemented types

Constructors

Attribution(AttributionAuthor? author, AttributionLink? link, Image? avatarImage)
factory

Properties

author → AttributionAuthor?
Additional information about the author.
no setter
avatarImage → Image?
no setter
hashCode → int
The hash code for this object.
no setteroverride
Link to a specific page on the author's site. To link to the website as a whole, use author.uri.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Attribution other) → bool
The equality operator.
override