AttributionAuthor class final

Available extensions

Constructors

AttributionAuthor({required String name, String? uri, String? email})
const

Properties

email → String?
Author's email. Must contain at least one @ symbol.
final
hashCode → int
The hash code for this object.
no setteroverride
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String?
A reference to the author's site.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant AttributionAuthor other) → bool
The equality operator.
override