BaseMapObjectCollection class abstract

Implemented types
Implementers

Constructors

BaseMapObjectCollection()

Properties

draggable ↔ bool
If true, the map object can be dragged by the user. Default: false.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
parent → BaseMapObjectCollection
Returns the collection of map objects that the current map object belongs to.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userData ↔ Object?
getter/setter pairinherited
visible ↔ bool
Manages visibility of the object on the map. Default: true.
getter/setter pairinherited
zIndex ↔ double
Gets the z-index, which affects:
getter/setter pairinherited

Methods

addListener(MapObjectCollectionListener collectionListener) → void
Adds a listener to track notifications of changes to the collection.
addTapListener(MapObjectTapListener tapListener) → void
Adds a tap listener to the object.
inherited
clear() → void
Removes all map objects from the collection.
isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(MapObject mapObject) → void
Removes the given map object from the collection.
removeListener(MapObjectCollectionListener collectionListener) → void
Removes a listener.
removeTapListener(MapObjectTapListener tapListener) → void
Removes the tap listener from the object.
inherited
setDragListener(MapObjectDragListener? dragListener) → void
Sets a drag listener for the object. Each object can only have one drag listener.
inherited
setVisible(Animation animation, {required bool visible, Callback? onFinished}) → void
Manages visibility of the object.
inherited
toString() → String
A string representation of this object.
inherited
traverse(MapObjectVisitor mapObjectVisitor) → void
Traverses through the collection with a visitor object. Used for iteration over map objects in the collection.

Operators

operator ==(Object other) → bool
The equality operator.
inherited