BoundingBox class final

A rectangular box around the object.

Available extensions

Constructors

BoundingBox(Point southWest, Point northEast)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
northEast → Point
The coordinates of the northeast corner of the box.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
southWest → Point
The coordinates of the southwest corner of the box.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant BoundingBox other) → bool
The equality operator.
override