BoundingBoxHelper class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getBounds(BoundingBox bbox) → BoundingBox
Gets bounds based on a bounding box.
getBoundsFromPoint(Point point) → BoundingBox
Gets bounds based on a point.
getBoundsFromPolygon(Polygon polygon) → BoundingBox
Gets bounds based on a polygon.
getBoundsFromPolyline(Polyline polyline) → BoundingBox
Gets bounds based on a polyline.
getBoundsFromRing(LinearRing ring) → BoundingBox
Gets bounds based on a linear ring.
getBoundsFromTwoBoxes(BoundingBox first, BoundingBox second) → BoundingBox
Gets bounds based on two bounding boxes.