CameraBounds class abstract

The object that is used to interact with the map bounds.

Implemented types

Constructors

CameraBounds()

Properties

hashCode → int
The hash code for this object.
no setterinherited
latLngBounds ↔ BoundingBox?
Latitudes should be in range [-89.3, 89.3]. Longitudes should be in range [-180, 180).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMaxZoom() → double
Maximum available zoom level considering zoom level hint provided via #setMaxZoomPreference
getMinZoom() → double
Minimum available zoom level considering zoom level hint provided via #setMinZoomPreference.
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetMinMaxZoomPreference() → void
Reset minimum and maximum available zoom level hints.
setMaxZoomPreference(double zoom) → void
Set maximum available zoom level hint.
setMinZoomPreference(double zoom) → void
Set minimum available zoom level hint.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited