CameraPosition class final

The position of the camera.

Available extensions

Constructors

CameraPosition(Point target, {required double zoom, required double azimuth, required double tilt})
const

Properties

azimuth → double
Angle between north and the direction of interest on the map plane, in degrees in the range [0, 360).
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target → Point
The point the camera is looking at.
final
tilt → double
Camera tilt in degrees. 0 means vertical downward.
final
zoom → double
Zoom level. 0 corresponds to the whole world displayed in a single tile.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant CameraPosition other) → bool
The equality operator.
override