Circle class final

A circle around the specified point.

Available extensions

Constructors

Circle(Point center, {required double radius})
const

Properties

center → Point
The coordinates of the center of the circle.
final
hashCode → int
The hash code for this object.
no setteroverride
radius → double
The radius of the circle in meters.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Circle other) → bool
The equality operator.
override