GeoObject class abstract final

Geo object. Can be displayed as a placemark, polyline, polygon, and other, depending on the geometry type.

Implemented types

Constructors

GeoObject(String? name, String? descriptionText, List<Geometry> geometry, BoundingBox? boundingBox, Map<String, Attribution> attributionMap, TypeDictionaryBase<BaseMetadata> metadataContainer, List<String> aref)
factory

Properties

aref → List<String>
The name of the internet resource.
no setter
attributionMap → Map<String, Attribution>
The attribution of information to a specific author.
no setter
boundingBox → BoundingBox?
A rectangular box around the object.
no setter
descriptionText → String?
The description of the object.
no setter
geometry → List<Geometry>
The object's geometry.
no setter
hashCode → int
The hash code for this object.
no setteroverride
metadataContainer → TypeDictionaryBase<BaseMetadata>
The object's metadata.
no setter
name → String?
Object name.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant GeoObject other) → bool
The equality operator.
override