GeoObjectCollectionItem class final

The geo objects in the collection.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asGeoObject() → GeoObject?
asGeoObjectCollection() → GeoObjectCollection?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onGeoObject(GeoObject value), required void onGeoObjectCollection(GeoObjectCollection value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited