GeoObjectSelectionMetadata class abstract final

Geo object metadata which is needed to select object.

Inheritance
Implemented types

Constructors

GeoObjectSelectionMetadata(String objectId, String dataSourceName, String layerId, int? groupId)
factory

Properties

dataSourceName → String
Data source name.
no setter
groupId → int?
Group ID.
no setter
hashCode → int
The hash code for this object.
no setteroverride
layerId → String
Layer ID.
no setter
objectId → String
Object ID.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant GeoObjectSelectionMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<GeoObjectSelectionMetadata>
final