Icon class abstract

Provides an interface to set icon and its style for a placemark.

Implemented types

Constructors

Icon()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style IconStyle
The style properties (scale, zIndex, etc.) of the icon placemark. Note: The current style cannot be modified directly - you must reset it to apply changes.
getter/setter pair

Methods

isValid() bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
Removes the presentation. This method invalidates object.
inherited
setImage(ImageProvider image, {IconStyle? style, Callback? onFinished}) → void
Sets the image for the icon.
setView(ViewProvider view, {IconStyle? style, Callback? onFinished}) → void
Sets the view for the icon.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited