IconStyle class final

The style of created icons.

Constructors

IconStyle({Point<double>? anchor, RotationType? rotationType, double? zIndex, bool? flat, bool? visible, double? scale, double opacity = 1.0, Rect? tappableArea})
const

Properties

anchor → Point<double>?
An anchor is used to alter image placement. Normalized: (0.0f, 0.0f) denotes the top left image corner; (1.0f, 1.0f) denotes bottom right. Default is (0.5f, 0.5f).
final
flat → bool?
If true, the icon is displayed on the map surface. If false, the icon is displayed on the screen surface. Default: false.
final
hashCode → int
The hash code for this object.
no setteroverride
opacity → double
Opacity of the icon
final
rotationType → RotationType?
Icon rotation type. Default: NoRotation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double?
Scale of the icon. Default: 1.0f.
final
tappableArea → Rect?
Tappable area on the icon. Coordinates are measured the same way as anchor coordinates. If rect is empty or invalid, the icon will not process taps. By default, icons process all taps.
final
visible → bool?
Sets icon visibility. Default: true.
final
zIndex → double?
Z-index of the icon, relative to the placemark's z-index.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant IconStyle other) → bool
The equality operator.
override