Image class abstract final

Implemented types

Constructors

Image(String urlTemplate, List<ImageImageSize> sizes, List<String> tags)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizes → List<ImageImageSize>
Image sizes.
no setter
tags → List<String>
Image tags.
no setter
urlTemplate → String
urlTemplate for the image.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Image other) → bool
The equality operator.
override