ImagesImageDataDescriptor class final

Available extensions

Constructors

ImagesImageDataDescriptor({required String imageId, Color? primaryColor, Color? secondaryColor, Color? tertiaryColor})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
imageId → String
final
primaryColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryColor → Color?
final
tertiaryColor → Color?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ImagesImageDataDescriptor other) → bool
The equality operator.
override