IndoorLevel class final

Describes level of indoor plan.

Available extensions

Constructors

IndoorLevel({required String id, required String name, required bool isUnderground})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String
Universal identifier of the level.
final
isUnderground → bool
true if level is under ground
final
name → String
Localized display name of the level.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant IndoorLevel other) → bool
The equality operator.
override