IndoorPlan class abstract

Describes indoor plan of building. Use activeLevelId property to select active level.

Implemented types

Constructors

IndoorPlan()

Properties

activeLevelId ↔ String
Gets/sets active id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
levels → List<IndoorLevel>
List of all levels in indoor plan, from bottom to top.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited