JamSegment class final

A segment of a traffic jam that has specific traffic conditions.

Available extensions

Constructors

JamSegment(JamType jamType, {required double speed})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
jamType → JamType
The type of the traffic jam.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double
The speed at which traffic is moving.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant JamSegment other) → bool
The equality operator.
override