JamStyle class abstract final

The style that is used to display traffic intensity.

Implemented types

Constructors

JamStyle(List<JamTypeColor> colors)
factory

Properties

colors → List<JamTypeColor>
Collection of colors for traffic intensity.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant JamStyle other) → bool
The equality operator.
override