LayerIds class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

advertPinsLayerId → String
no setter
buildingsLayerId → String
no setter
drivingNavigationBalloonsLayerId → String
no setter
drivingNavigationBaseLayerId → String
no setter
drivingNavigationRoutePinsLayerId → String
no setter
drivingNavigationUserPlacemarkLayerId → String
no setter
jamsLayerId → String
Deprecated. There is no separate jams layer anymore.
no setter
mapLayerId → String
no setter
mapObjectsLayerId → String
no setter
personalizedPoiLayerId → String
Deprecated. There is no separate ppoi layer anymore.
no setter
roadEventsLayerId → String
no setter
routeMapObjectsLayerId → String
no setter
searchPinsLayerId → String
no setter
transportLayerId → String
no setter
userLocationLayerId → String
no setter