LayerOptionsNative class final

Inheritance
Implemented types
Available extensions

Constructors

LayerOptionsNative()

Properties

active ↔ bool
getter/setter pair
address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
animateOnActivation ↔ bool
getter/setter pair
cacheable ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nightModeAvailable ↔ bool
getter/setter pair
overzoomMode ↔ int
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileAppearingAnimationDuration ↔ NativeInterval
getter/setter pair
transparent ↔ bool
getter/setter pair
versionSupport ↔ bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited