LineStyleNative class final

Inheritance
Implemented types
Available extensions

Constructors

LineStyleNative()

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
arcApproximationStep ↔ double
getter/setter pair
dashLength ↔ double
getter/setter pair
dashOffset ↔ double
getter/setter pair
gapLength ↔ double
getter/setter pair
gradientLength ↔ double
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
innerOutlineEnabled ↔ bool
getter/setter pair
outlineColor ↔ NativeColor
getter/setter pair
outlineWidth ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth ↔ double
getter/setter pair
turnRadius ↔ double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited