LocalizedValue class final

A value respecting the device locale.

Available extensions

Constructors

LocalizedValue({required double value, required String text})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
Localized text. For example: "15 ft" or "42 km".
final
value → double
Value in SI units for distance, speed and duration.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant LocalizedValue other) → bool
The equality operator.
override