Location class final

The geographical position of the object.

Available extensions

Constructors

Location(Point position, DateTime absoluteTimestamp, DateTime relativeTimestamp, {double? accuracy, double? altitude, double? altitudeAccuracy, double? heading, double? speed, String? indoorLevelId})
const

Properties

absoluteTimestamp → DateTime
Absolute timestamp, in milliseconds since January 1, 1970.
final
accuracy → double?
Location accuracy in meters.
final
altitude → double?
The altitude of the location in meters.
final
altitudeAccuracy → double?
The accuracy of the altitude in meters.
final
hashCode → int
The hash code for this object.
no setteroverride
heading → double?
The current heading in degrees relative to true north, clockwise.
final
indoorLevelId → String?
The universal identifier of indoor level.
final
position → Point
The geographical position.
final
relativeTimestamp → DateTime
Relative timestamp, number of milliseconds passed on steady clock. Use for interval calculation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double?
The speed in meters per second.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Location other) → bool
The equality operator.
override