LocationSettings class final

Constructors

LocationSettings({bool provideAccuracy = false, Range? accuracy, TimeInterval? locationTimeInterval, bool provideSpeed = false, double speed = 0.0, bool provideHeading = false, Range? headingError, LocationError? locationError, bool provideWheelSpeed = false, TimeInterval? wheelSpeedTimeInterval})
const

Properties

accuracy → Range?
Location accuracy range in meters.
final
hashCode → int
The hash code for this object.
no setteroverride
headingError → Range?
The current heading error range in degrees relative to true heading, clockwise.
final
locationError → LocationError?
final
locationTimeInterval → TimeInterval?
Location time interval in milliseconds.
final
provideAccuracy → bool
Flag whether to provide accuracy value.
final
provideHeading → bool
Flag whether to provide error of heading.
final
provideSpeed → bool
Flag whether to provide speed value.
final
provideWheelSpeed → bool
Flag whether to provide wheel speed value.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed → double
The speed in meters per second.
final
wheelSpeedTimeInterval → TimeInterval?
Time interval of getting the wheel speed in milliseconds. After publication the wheel speed corresponds to the speed value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant LocationSettings other) → bool
The equality operator.
override