LocationSubscriptionSettings class final

Available extensions

Constructors

LocationSubscriptionSettings(LocationUseInBackground useInBackground, Purpose purpose)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
purpose → Purpose
Defines for what purpose the locations from the subscription will be used. Depending on the purpose, it tries to optimize requests for locations.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useInBackground → LocationUseInBackground
If UseInBackground is Allow then the 'location' flag must be set in 'UIBackgroundModes' of the application.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant LocationSubscriptionSettings other) → bool
The equality operator.
override