buildingsAboveIndoorEnabled property
bool
get
buildingsAboveIndoorEnabled
If set to true, hides the indoor plans and shows the buildings without resetting the current indoor plan. False by default.
Implementation
core.bool get buildingsAboveIndoorEnabled;
set
buildingsAboveIndoorEnabled
(bool val)
Implementation
set buildingsAboveIndoorEnabled(core.bool val);