MapLoadStatistics class final

The time it took to load map elements.

Available extensions

Constructors

MapLoadStatistics(Duration curZoomGeometryLoaded, Duration curZoomPlacemarksLoaded, Duration curZoomLabelsLoaded, Duration delayedGeometryLoaded, Duration curZoomModelsLoaded, Duration fullyLoaded, Duration fullyAppeared, {required int renderObjectCount, required int tileMemoryUsage})
const

Properties

curZoomGeometryLoaded → Duration
final
curZoomLabelsLoaded → Duration
final
curZoomModelsLoaded → Duration
The time it took to load models.
final
curZoomPlacemarksLoaded → Duration
final
delayedGeometryLoaded → Duration
The time it took to load delayed geometry.
final
fullyAppeared → Duration
The time it took for all map objects to appear.
final
fullyLoaded → Duration
The time it took to load all map objects.
final
hashCode → int
The hash code for this object.
no setteroverride
renderObjectCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileMemoryUsage → int
Tile memory usage in bytes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MapLoadStatistics other) → bool
The equality operator.
override