MapObject class abstract

An object displayed on the map.

Implemented types
Implementers

Constructors

MapObject()

Properties

draggable ↔ bool
If true, the map object can be dragged by the user. Default: false.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parent → BaseMapObjectCollection
Returns the collection of map objects that the current map object belongs to.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userData ↔ Object?
getter/setter pair
visible ↔ bool
Manages visibility of the object on the map. Default: true.
getter/setter pair
zIndex ↔ double
Gets the z-index, which affects:
getter/setter pair

Methods

addTapListener(MapObjectTapListener tapListener) → void
Adds a tap listener to the object.
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTapListener(MapObjectTapListener tapListener) → void
Removes the tap listener from the object.
setDragListener(MapObjectDragListener? dragListener) → void
Sets a drag listener for the object. Each object can only have one drag listener.
setVisible(Animation animation, {required bool visible, Callback? onFinished}) → void
Manages visibility of the object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited