MapObjectVisitor class abstract

Used to traverse over the children of the MapObjectCollection.

Constructors

MapObjectVisitor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onCircleVisited(CircleMapObject circle) → void
Called when a circle is visited.
onClusterizedCollectionVisitEnd(ClusterizedPlacemarkCollection collection) → void
Called for visited clusterized placemark collections only. If an exception occurred during the visit, the method might be skipped.
onClusterizedCollectionVisitStart(ClusterizedPlacemarkCollection collection) → bool
Called for clusterized placemark collection. The collection is ignored if this method returns false.
onCollectionVisitEnd(MapObjectCollection collection) → void
Called for visited collections only. If an exception occurred during the visit, the method might be skipped.
onCollectionVisitStart(MapObjectCollection collection) → bool
Called for every child collection. The collection is ignored if this method returns false.
onPlacemarkVisited(PlacemarkMapObject placemark) → void
Called when a placemark is visited.
onPolygonVisited(PolygonMapObject polygon) → void
Called when a polygon is visited.
onPolylineVisited(PolylineMapObject polyline) → void
Called when a polyline is visited.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited