setMaxFps abstract method
Allows to reduce CPU/GPU/battery usage in specific scenarios, where lower framerate is acceptable. Valid range: [0,
Implementation
void setMaxFps(core.int fps);
Allows to reduce CPU/GPU/battery usage in specific scenarios, where lower framerate is acceptable. Valid range: [0,
void setMaxFps(core.int fps);