Model class abstract

describes model presentation of PlacemarkMapObject

Implemented types

Constructors

Model()

Properties

hashCode → int
The hash code for this object.
no setterinherited
modelStyle ↔ ModelStyle
The style properties (scale, unitType, etc.) of the model placemark. Note: The current style cannot be modified directly - you must reset it to apply changes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove() → void
Removes the presentation. This method invalidates object.
inherited
setData(DataProviderWithId gltfDataProvider, {Callback? onFinished}) → void
Sets glTF data provider.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited