ModelStyle class final

The style of the model.

Constructors

ModelStyle({double scale = 1.0, ModelStyleUnitType unitType = ModelStyleUnitType.Unit, ModelStyleRenderMode renderMode = ModelStyleRenderMode.UserModel, String? variantName})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
renderMode → ModelStyleRenderMode
Defines should it be rendered with buildings from ground layer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
Scale the model by this value.
final
unitType → ModelStyleUnitType
Unit type of the model.
final
variantName → String?
Name of variant to render model with. See KHR_materials_variants gltf extension. This works only for glTF models.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant ModelStyle other) → bool
The equality operator.
override