MultiPolygon class abstract final

An area consisting of multiple external polygons.

Implemented types

Constructors

MultiPolygon(List<Polygon> polygons)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
polygons → List<Polygon>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MultiPolygon other) → bool
The equality operator.
override