ObjectEvent class abstract

Base abstract class for an object event. Layers that produce object event callbacks need to provide derived event classes.

Implemented types
Implementers

Constructors

ObjectEvent()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited