OfflineCacheRegion class final

@attention This feature is not available in the free MapKit version.

Available extensions

Constructors

OfflineCacheRegion(Point center, LocalizedValue size, DateTime releaseTime, {required int id, required String name, required String country, int? parentId})
const

Properties

center → Point
Center point.
final
country → String
Country of the region.
final
hashCode → int
The hash code for this object.
no setteroverride
id → int
Region ID.
final
name → String
Name of the region.
final
parentId → int?
Region id of the parent region.
final
releaseTime → DateTime
Returns the region creation time.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → LocalizedValue
Region size
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant OfflineCacheRegion other) → bool
The equality operator.
override