OverzoomMode enum

Inheritance
Available extensions

Values

Disabled → const OverzoomMode

Overzoom is fully disabled.

Enabled → const OverzoomMode

If a tile is absent or translucent, tiles from lower or higher zooms will be shown.

WithPrefetch → const OverzoomMode

Same as Enabled, plus it fetches tiles well below absent or translucent tiles that don't have any overzoom tiles to replace them with.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<OverzoomMode>
A constant List of the values in this enum, in order of their declaration.