PersonalizedPoiExtraMetadataEntry class abstract final

Inheritance
Implemented types

Constructors

PersonalizedPoiExtraMetadataEntry(String? key, String? value)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
key → String?
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant PersonalizedPoiExtraMetadataEntry other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<PersonalizedPoiExtraMetadataEntry>
final