PlacemarkAnimation class abstract

Provides an interface to load and control animation of placemark.

Implemented types

Constructors

PlacemarkAnimation()

Properties

hashCode → int
The hash code for this object.
no setterinherited
reversed ↔ bool
If true, animation will be played in the reverse direction. Default value is false.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Pauses animation.
play() → void
Starts animation. Removes the current play callback. Same as play(null).
playWithCallback(Callback onFinished) → void
Starts animation and handles the callback.
remove() → void
Removes the presentation. This method invalidates object.
inherited
resume() → void
Resumes paused animation. Callback (if any) is NOT removed.
setIcon(AnimatedImageProvider image, IconStyle style) → void
Sets the animated image and icon style. The new animation will be in the paused state.
setIconStyle(IconStyle style) → void
Changes the icon style.
setIconWithCallback(AnimatedImageProvider image, IconStyle style, Callback onFinished) → void
Sets the animated image and icon style. The new animation will be in the paused state.
stop() → void
Stops animation. Animation returns to the initial paused state.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited