PlacemarkMapObject class abstract

Represents a geo-positioned object on the map.

Implemented types

Constructors

PlacemarkMapObject()

Properties

direction ↔ double
Angle between the direction of an object and the direction to north. Measured in degrees. Default: 0.f.
getter/setter pair
draggable ↔ bool
If true, the map object can be dragged by the user. Default: false.
getter/setter pairinherited
geometry ↔ Point
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
opacity ↔ double
Opacity multiplicator for the placemark content. Values below 0 will be set to 0. Default: 1.
getter/setter pair
parent → BaseMapObjectCollection
Returns the collection of map objects that the current map object belongs to.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → PlacemarkText
PlacemarkText can be used to set text and its style for the placemark. It's optional parameter and can be used in addition to placemark objects
no setter
userData ↔ Object?
getter/setter pairinherited
visible ↔ bool
Manages visibility of the object on the map. Default: true.
getter/setter pairinherited
zIndex ↔ double
Gets the z-index, which affects:
getter/setter pairinherited

Methods

addTapListener(MapObjectTapListener tapListener) → void
Adds a tap listener to the object.
inherited
isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTapListener(MapObjectTapListener tapListener) → void
Removes the tap listener from the object.
inherited
setDragListener(MapObjectDragListener? dragListener) → void
Sets a drag listener for the object. Each object can only have one drag listener.
inherited
setIcon(ImageProvider image) → void
Sets an icon with the default style for the placemark. Switches off and resets model/composite icon/animation/view.
setIconStyle(IconStyle style) → void
Changes the icon style. Valid only for the single icon, the view and the animated icon.
setIconWithCallback(ImageProvider image, Callback onFinished) → void
Sets an icon with the default style for the placemark. Switches off and resets model/composite icon/animation/view. The callback is called immediately after the image finished loading. This means you can, for example, change the placemark visibility with a new icon.
setIconWithStyle(ImageProvider image, IconStyle style) → void
Sets an icon with the given style for the placemark. Switches off and resets model/composite icon/animation/view.
setIconWithStyleAndCallback(ImageProvider image, IconStyle style, Callback onFinished) → void
Sets an icon with the given style for the placemark. Switches off and resets model/composite icon/animation/view. The callback is called immediately after the image finished loading. This means you can, for example, change the placemark visibility with a new icon.
setScaleFunction(List<Point<double>> points) → void
Sets piecewise linear scale, depending on the zoom. The 'points' must be sorted by x; x coordinates must be unique. If zoom < minZoom(points) or zoom > maxZoom(points), it is set within the defined bounds before applying the function. By default, the scale function is defined by a single point (1, 1). If points is null or points.empty(), it resets the function to the default. If points.size() == 1, the scale is constant and equals point.y.
setText(String text) → void
Sets the text for the placemark, current text style is used
setTextStyle(TextStyle style) → void
Changes the text style.
setTextWithStyle(TextStyle style, {required String text}) → void
Sets the text with the given style for the placemark
setView(ViewProvider view) → void
Sets the view with the default style for the placemark. Switches off and resets icon/composite icon/animation/model.
setViewWithCallback(ViewProvider view, Callback onFinished) → void
Sets the view with the default style for the placemark. Switches off and resets icon/composite icon/animation/view. The callback will be called immediately after the view finished loading.
setViewWithStyle(ViewProvider view, IconStyle style) → void
Sets the view with the given style for the placemark. Switches off and resets icon/composite icon/animation/view.
setViewWithStyleAndCallback(ViewProvider view, IconStyle style, Callback onFinished) → void
Sets the view with the given style for the placemark. Switches off and resets icon/composite icon/animation/view. The callback will be called immediately after the view finished loading.
setVisible(Animation animation, {required bool visible, Callback? onFinished}) → void
Manages visibility of the object.
inherited
toString() → String
A string representation of this object.
inherited
useAnimation() → PlacemarkAnimation
Returns PlacemarkAnimation object that can be used to control animation of the placemark. Switches off and resets icon/composite icon/model/view.
useCompositeIcon() → CompositeIcon
Returns CompositeIcon object that can be used to set icons and their styles for the placemark. Switches off and resets icon/model/animation/view.
useIcon() → Icon
Returns Icon object that can be used to set image or view and its style for the placemark. Switches off and resets composite icon/model/animation/view.
useModel() → Model
Returns Model object that can be used to set model and its style for the placemark. Switches off and resets icon/composite icon/animation/view.

Operators

operator ==(Object other) → bool
The equality operator.
inherited