Point class final

A point at the specified coordinates.

Available extensions

Constructors

Point({required double latitude, required double longitude})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
latitude → double
The point's latitude.
final
longitude → double
The point's longitude.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Point other) → bool
The equality operator.
override