Polygon class abstract final

A polygon with one or more polygons in it. The exterior and interior areas are specified using LinearRing.

Implemented types

Constructors

Polygon(LinearRing outerRing, List<LinearRing> innerRings)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
innerRings → List<LinearRing>
The list of rings in the specified area.
no setter
outerRing → LinearRing
The ring specifying the area.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Polygon other) → bool
The equality operator.
override