PolygonMapObject class abstract

A polygon displayed on the map.

Implemented types

Constructors

PolygonMapObject()

Properties

draggable ↔ bool
If true, the map object can be dragged by the user. Default: false.
getter/setter pairinherited
fillColor ↔ Color
Sets the fill color. Default: hexademical RGBA code 0x0066FF99. @attention Fill color is ignored if a pattern is set.
getter/setter pair
geodesic ↔ bool
The object geometry can be interpreted in two different ways:
getter/setter pair
geometry ↔ Polygon
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parent → BaseMapObjectCollection
Returns the collection of map objects that the current map object belongs to.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor ↔ Color
Sets the stroke color. Default: hexademical RGBA code 0x0066FFFF. Setting the stroke color to any transparent color (for example, RGBA code 0x00000000) effectively disables the stroke.
getter/setter pair
strokeWidth ↔ double
Sets the stroke width in units. Default: 5. The size of a unit is equal to the size of a pixel at the current zoom when the camera position's tilt is equal to 0 and the scale factor is equal to 1.
getter/setter pair
userData ↔ Object?
getter/setter pairinherited
visible ↔ bool
Manages visibility of the object on the map. Default: true.
getter/setter pairinherited
zIndex ↔ double
Gets the z-index, which affects:
getter/setter pairinherited

Methods

addTapListener(MapObjectTapListener tapListener) → void
Adds a tap listener to the object.
inherited
isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTapListener(MapObjectTapListener tapListener) → void
Removes the tap listener from the object.
inherited
resetPattern() → void
Removes pattern.
setAnimatedPattern(AnimatedImageProvider animatedImage, {required double scale}) → void
Sets pattern to fill polygon. @attention Original linear sizes of pattern should be equal to power of 2. @attention Fill color is ignored if a pattern is set.
setDragListener(MapObjectDragListener? dragListener) → void
Sets a drag listener for the object. Each object can only have one drag listener.
inherited
setPattern(ImageProvider image, {required double scale}) → void
Sets pattern to fill polygon. @attention Original linear sizes of pattern should be equal to power of 2. @attention Fill color is ignored if pattern is set.
setVisible(Animation animation, {required bool visible, Callback? onFinished}) → void
Manages visibility of the object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited