PolylineIndex class abstract

Provides methods for binding locations to a polyline

Implemented types

Constructors

PolylineIndex()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

closestPolylinePosition(Point point, PolylinePosition positionFrom, PolylinePosition positionTo, {required double maxLocationBias}) → PolylinePosition?
Finds the closest polyline position between the two positions. Returns null if there is no position that satisfies the condition distance(point, position) < maxLocationBias.
closestPolylinePositionWithPriority(Point point, PolylineIndexPriority priority, {required double maxLocationBias}) → PolylinePosition?
Finds closest polyline position. Returns null if there is no position that satisfies the condition distance(point, position) < maxLocationBias.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited