PolylineUtils class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

advancePolylinePosition(Polyline polyline, PolylinePosition position, {required double distance}) → PolylinePosition
Advance the polyline position by a specified distance in meters.
createPolylineIndex(Polyline polyline) → PolylineIndex
Creates PolylineIndex for polyline. See mapkit_geometry_geo_polyline_index.PolylineIndex for details.
distanceBetweenPolylinePositions(Polyline polyline, PolylinePosition from, PolylinePosition to) → double
pointByPolylinePosition(Polyline geometry, PolylinePosition position) → Point
The point in the polyline.
positionsOfFork(Polyline firstPolyline, PolylinePosition firstPolylinePosition, Polyline secondPolyline, PolylinePosition secondPolylinePosition) → List<PolylinePosition>
The position of the fork on the road.