RawTile class abstract final

A raw tile that can be displayed on the map.

Implemented types

Constructors

RawTile(Version version, Map<String, String> features, String etag, RawTileUseCache useCache, RawTileState state, ByteBuffer rawData)
factory

Properties

etag → String
no setter
features → Map<String, String>
no setter
hashCode → int
The hash code for this object.
no setteroverride
rawData → ByteBuffer
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → RawTileState
no setter
useCache → RawTileUseCache
no setter
version → Version
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant RawTile other) → bool
The equality operator.
override