RoutePosition class abstract

Implemented types

Constructors

RoutePosition()

Properties

hashCode → int
The hash code for this object.
no setterinherited
point → Point
As point on the map
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

advance(double distance) → RoutePosition
Create position shifted by distance. If the distance is more than remains route length, the end of the route will be returned. If the distance is less than a negative distance from the start, the beginning of the route will be returned.
distanceTo(RoutePosition to) → double?
Distance to another point on the route. Return none if point on another route. May be less 0 if position "to" stay before this position.
distanceToFinish() → double
Distance to the end of the route.
equals(RoutePosition another) → bool
Determines if position equals another position on the route. Throws if another position belongs to another route.
heading() → double
Heading movement on the route at this position. It is equal heading of the segment which is belonged position.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRoute(String routeId) → bool
Check if this position on the same route as passed.
positionOnRoute(String routeId) → PolylinePosition?
Return polyline position on route. If the position not on the passed route none will be returned.
precedes(RoutePosition another) → bool
Determines if position precedes another position on the route. Throws if another position belongs to another route.
precedesOrEquals(RoutePosition another) → bool
Determines if position precedes or equals another position on the route. Throws if another position belongs to another route.
timeToFinish() → double
Time to the end of the route.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited