Segment class final

A line between two points.

Available extensions

Constructors

Segment(Point startPoint, Point endPoint)
const

Properties

endPoint → Point
End point of the segment.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startPoint → Point
Starting point of the segment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Segment other) → bool
The equality operator.
override