SimulationSettings class abstract final

Implemented types

Constructors

SimulationSettings(Polyline geometry, LocationSettings locationSettings)
factory

Properties

geometry → Polyline
no setter
hashCode → int
The hash code for this object.
no setteroverride
locationSettings → LocationSettings
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SimulationSettings other) → bool
The equality operator.
override