Span class final

The panorama field of view.

Available extensions

Constructors

Span({required double horizontalAngle, required double verticalAngle})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
horizontalAngle → double
The horizontal view angle.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verticalAngle → double
The vertical view angle.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Span other) → bool
The equality operator.
override