SpannableString class abstract final

A string that supports spans in it.

Implemented types

Constructors

SpannableString(String text, List<SpannableStringSpan> spans)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spans → List<SpannableStringSpan>
The spans in stored text.
no setter
text → String
The text of the spannable string.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SpannableString other) → bool
The equality operator.
override