Subpolyline class final

A part of a polyline.

Available extensions

Constructors

Subpolyline(PolylinePosition begin, PolylinePosition end)
const

Properties

begin → PolylinePosition
The start of the selected part of the polyline.
final
end → PolylinePosition
The end of the selected part of the polyline.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Subpolyline other) → bool
The equality operator.
override