TaxiMoney class final

Available extensions

Constructors

TaxiMoney({required double value, required String text, required String currency})
const

Properties

currency → String
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
value → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant TaxiMoney other) → bool
The equality operator.
override