TileDataSource class abstract

Implemented types

Constructors

TileDataSource()

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
Stores id of data source.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

invalidate(String version) → void
Invalidates data source and reloads all tiles. Must not be called if DataSource does not support versioning: LayerOptions.versionSupport = false;
isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited