TileId class final

The ID of a tile on the map.

Available extensions

Constructors

TileId({required int x, required int y, required int z})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → int
The number of the tile horizontally.
final
y → int
The number of the tile vertically.
final
z → int
The number of columns and rows to split the map into.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant TileId other) → bool
The equality operator.
override