Time class final

Time in I18nTime format.

Available extensions

Constructors

Time({required int value, required int tzOffset, required String text})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
The description of the timer.
final
tzOffset → int
Time offset to account for time zones.
final
value → int
Time value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant Time other) → bool
The equality operator.
override