TrafficLevel class final

The level of traffic.

Available extensions

Constructors

TrafficLevel(TrafficColor color, {required int level})
const

Properties

color TrafficColor
The color that represents traffic.
final
hashCode int
The hash code for this object.
no setteroverride
level int
Traffic level.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(covariant TrafficLevel other) bool
The equality operator.
override