UserData class abstract final

Describes data attached to features in user layer.

Inheritance
Implemented types

Constructors

UserData(Map<String, String> data)
factory

Properties

data → Map<String, String>
A dictionary of data.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant UserData other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<UserData>
final