UserLocationIconChanged class abstract

This event triggers when the user location icon type is changed.

Implemented types

Constructors

UserLocationIconChanged()

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconType → UserLocationIconType
Gets the type of user location icon used.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited