UserLocationView class abstract

Use this interface to specify the appearance of the user location icon elements.

Implemented types

Constructors

UserLocationView()

Properties

accuracyCircle → CircleMapObject
Gets the GPS accuracy circle map object.
no setter
arrow → PlacemarkMapObject
Gets the location arrow map object.
no setter
hashCode → int
The hash code for this object.
no setterinherited
pin → PlacemarkMapObject
Gets the location pin map object.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited