VisibleRegion class final

Defines the visible region.

Available extensions

Constructors

VisibleRegion(Point topLeft, Point topRight, Point bottomLeft, Point bottomRight)
const

Properties

bottomLeft → Point
Bottom-left of the visible region.
final
bottomRight → Point
Bottom-right of the visible region.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLeft → Point
Top-left of the visible region.
final
topRight → Point
Top-right of the visible region.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant VisibleRegion other) → bool
The equality operator.
override