XYPoint class final

World coordinates.

Available extensions

Constructors

XYPoint({required double x, required double y})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
The horizontal position of the point.
final
y → double
The vertical position of the point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant XYPoint other) → bool
The equality operator.
override