ModelProvider class

Constructors

ModelProvider(ImageProvider texture, {required Future<ByteData> onModelRequest(), String? modelId, Function? onError})

Properties

hashCode → int
The hash code for this object.
no setterinherited
modelId → String
final
onModelRequest → Future<ByteData> Function()
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texture → ImageProvider
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited