subscribe abstract method
Subscribes a listener to receive log messages.
The class does not retain the object in the 'logListener' parameter. It is your responsibility to maintain a strong reference to the target object while it is attached to a class.
logListener The listener to subscribe.
Implementation
void subscribe(LogListener logListener);