ViewProvider class

Constructors

ViewProvider({FlutterView? view, required FutureOr<Widget> builder(), TextDirection textDirection = TextDirection.ltr, String? id, bool cacheable = false, Function? onError})

Properties

cacheable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
onError → Function?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → TextDirection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited