transparentBackgroundEnabled property
bool
get
transparentBackgroundEnabled
If enabled, the map background will be fully transparent. Note: the underlying platform view must be created with transparency support enabled for this flag to take effect (e.g. on Android, set the 'transparent' XML attribute on MapView; ; on iOS, create the MapView with transparencySupport: true).
Implementation
core.bool get transparentBackgroundEnabled;
set
transparentBackgroundEnabled
(bool val)
Implementation
set transparentBackgroundEnabled(core.bool val);