Logging class abstract

Interface for subscribing to and unsubscribing from log messages.

Implemented types

Constructors

Logging()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(LogListener logListener) → void
Subscribes a listener to receive log messages.
toString() String
A string representation of this object.
inherited
unsubscribe(LogListener logListener) → void
Unsubscribes a listener from receiving log messages.

Operators

operator ==(Object other) bool
The equality operator.
inherited