unsubscribe abstract method
Unsubscribes a listener from receiving log messages.
The class does not retain the object in the 'logListener' parameter. It is your responsibility to maintain a strong reference to the target object while it is attached to a class.
logListener The listener to unsubscribe.
Implementation
void unsubscribe(LogListener logListener);